================
centra-py-client
================


.. image:: https://img.shields.io/pypi/v/centra_py_client.svg
        :target: https://pypi.python.org/pypi/centra_py_client

.. image:: https://img.shields.io/travis/guardicode/centra_py_client.svg
        :target: https://travis-ci.com/guardicode/centra_py_client

.. image:: https://readthedocs.org/projects/centra-py-client/badge/?version=latest
        :target: https://centra-py-client.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python client for Centra API access. Visit Guardicore_'s website for more information about Centra!

Find the full client documentation at https://centra-py-client.readthedocs.io (locally, `/docs` folder).

.. _Guardicore: https://guardicore.com
